# Generated by roxygen2: do not edit by hand

S3method(gof,default)
S3method(gof,rga)
S3method(plot,duane)
S3method(plot,duane_predict)
S3method(plot,exposure)
S3method(plot,mcf)
S3method(plot,nhpp)
S3method(plot,nhpp_predict)
S3method(plot,rga)
S3method(plot,rga_predict)
S3method(print,duane)
S3method(print,duane_predict)
S3method(print,exposure)
S3method(print,gof)
S3method(print,mcf)
S3method(print,nhpp)
S3method(print,nhpp_predict)
S3method(print,rdt)
S3method(print,rga)
S3method(print,rga_predict)
export(duane)
export(exposure)
export(gof)
export(grwr_api)
export(mcf)
export(nhpp)
export(overlay_nhpp)
export(overlay_rga)
export(ppplot.rga)
export(predict_duane)
export(predict_nhpp)
export(predict_rga)
export(qqplot.rga)
export(rdt)
export(rga)
export(rga_mcp_server)
export(sim_failures)
export(weibull_to_rga)
import(plumber)
importFrom(grDevices,palette)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(segmented,intercept)
importFrom(segmented,seg.control)
importFrom(segmented,segmented)
importFrom(segmented,slope)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,aggregate)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,lsfit)
importFrom(stats,optim)
importFrom(stats,predict)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,residuals)
importFrom(stats,runif)
importFrom(stats,uniroot)
