
# plumb-rga.R
# Functions rga(), print.rga(), plot.rga(), predict_rga(), print.rga_predict(),
# and plot.rga_predict() are provided by the ReliaGrowR package loaded via
# library(ReliaGrowR) in plumber.R. No local definitions needed.
