% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/exposure.R
\name{print.exposure}
\alias{print.exposure}
\title{Print Method for exposure Objects.}
\usage{
\method{print}{exposure}(x, ...)
}
\arguments{
\item{x}{An object of class \code{exposure}.}

\item{...}{Additional arguments (not used).}
}
\value{
Invisibly returns the input object.
}
\description{
Prints a summary of the exposure analysis results.
}
\examples{
id   <- c(1, 1, 2, 2)
time <- c(100, 200, 150, 300)
result <- exposure(id, time)
print(result)
}
\seealso{
Other Repairable Systems Analysis: 
\code{\link{exposure}()},
\code{\link{mcf}()},
\code{\link{nhpp}()},
\code{\link{overlay_nhpp}()},
\code{\link{plot.exposure}()},
\code{\link{plot.mcf}()},
\code{\link{plot.nhpp}()},
\code{\link{plot.nhpp_predict}()},
\code{\link{predict_nhpp}()},
\code{\link{print.mcf}()},
\code{\link{print.nhpp}()},
\code{\link{print.nhpp_predict}()}
}
\concept{Repairable Systems Analysis}
