% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcf.R
\name{plot.mcf}
\alias{plot.mcf}
\title{Plot Method for mcf Objects.}
\usage{
\method{plot}{mcf}(x, conf_bounds = TRUE, legend = TRUE, legend_pos = "topleft", ...)
}
\arguments{
\item{x}{An object of class \code{mcf}.}

\item{conf_bounds}{Logical; include confidence bounds (default: TRUE).}

\item{legend}{Logical; show the legend (default: TRUE).}

\item{legend_pos}{Position of the legend (default: "topleft").}

\item{...}{Additional arguments passed to \code{plot()}.}
}
\value{
Invisibly returns \code{NULL}.
}
\description{
Plots the Mean Cumulative Function with optional confidence bounds.
}
\examples{
id <- c(1, 1, 1, 2, 2, 3, 3, 3, 3)
time <- c(100, 300, 500, 150, 400, 50, 200, 350, 600)
result <- mcf(id, time)
plot(result, main = "Mean Cumulative Function")
}
\seealso{
Other Repairable Systems Analysis: 
\code{\link{exposure}()},
\code{\link{mcf}()},
\code{\link{nhpp}()},
\code{\link{overlay_nhpp}()},
\code{\link{plot.exposure}()},
\code{\link{plot.nhpp}()},
\code{\link{plot.nhpp_predict}()},
\code{\link{predict_nhpp}()},
\code{\link{print.exposure}()},
\code{\link{print.mcf}()},
\code{\link{print.nhpp}()},
\code{\link{print.nhpp_predict}()}
}
\concept{Repairable Systems Analysis}
