% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rga.R
\name{print.rga_predict}
\alias{print.rga_predict}
\title{Print Method for rga_predict Objects}
\usage{
\method{print}{rga_predict}(x, ...)
}
\arguments{
\item{x}{An object of class \code{rga_predict}.}

\item{...}{Additional arguments (not used).}
}
\value{
Invisibly returns the input object.
}
\description{
Prints a formatted table of forecast cumulative failures with confidence
bounds for an \code{rga_predict} object.
}
\examples{
times <- c(100, 200, 300, 400, 500)
failures <- c(1, 2, 1, 3, 2)
fit <- rga(times, failures)
fc <- predict_rga(fit, times = c(1500, 2000))
print(fc)
}
\seealso{
Other Reliability Growth Analysis: 
\code{\link{overlay_rga}()},
\code{\link{plot.rga}()},
\code{\link{plot.rga_predict}()},
\code{\link{predict_rga}()},
\code{\link{print.rga}()},
\code{\link{rga}()}
}
\concept{Reliability Growth Analysis}
