% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nhpp.R
\name{plot.nhpp}
\alias{plot.nhpp}
\title{Plot Method for nhpp Objects.}
\usage{
\method{plot}{nhpp}(x, conf_bounds = TRUE, legend = TRUE, legend_pos = "topleft", ...)
}
\arguments{
\item{x}{An object of class \code{nhpp}.}

\item{conf_bounds}{Logical; include confidence bounds (default: TRUE).}

\item{legend}{Logical; show the legend (default: TRUE).}

\item{legend_pos}{Position of the legend (default: "topleft").}

\item{...}{Additional arguments passed to \code{plot()}.}
}
\value{
Invisibly returns \code{NULL}.
}
\description{
Plots observed cumulative events with the fitted NHPP model and optional
confidence bounds.
}
\examples{
time <- c(200, 400, 600, 800, 1000)
event <- c(3, 5, 4, 7, 6)
result <- nhpp(time, event)
plot(result, main = "Power Law NHPP", xlab = "Time", ylab = "Cumulative Events")
}
\seealso{
Other Repairable Systems Analysis: 
\code{\link{exposure}()},
\code{\link{mcf}()},
\code{\link{nhpp}()},
\code{\link{overlay_nhpp}()},
\code{\link{plot.exposure}()},
\code{\link{plot.mcf}()},
\code{\link{plot.nhpp_predict}()},
\code{\link{predict_nhpp}()},
\code{\link{print.exposure}()},
\code{\link{print.mcf}()},
\code{\link{print.nhpp}()},
\code{\link{print.nhpp_predict}()}
}
\concept{Repairable Systems Analysis}
